pitchtools.IntervalVector
=========================

.. abjad-lineage:: abjad.tools.pitchtools.IntervalVector.IntervalVector

.. autoclass:: abjad.tools.pitchtools.IntervalVector.IntervalVector

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.clear
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.copy
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.custom_identifier
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.elements
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.from_selection
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.item_class
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.items
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.iteritems
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.iterkeys
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.itervalues
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.keys
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.most_common
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.subtract
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.update
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.values
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.viewitems
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.viewkeys
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.viewvalues
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__add__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__and__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__contains__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__delitem__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__eq__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__format__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__getitem__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__iter__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__len__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__makenew__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__missing__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__ne__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__or__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__repr__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__setitem__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__str__
      ~abjad.tools.pitchtools.IntervalVector.IntervalVector.__sub__

Bases
-----

- :py:class:`pitchtools.Vector <abjad.tools.pitchtools.Vector.Vector>`

- :py:class:`datastructuretools.TypedCounter <abjad.tools.datastructuretools.TypedCounter.TypedCounter>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalVector.IntervalVector.item_class
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.pitchtools.IntervalVector.IntervalVector.custom_identifier
   :noindex:

Methods
-------

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.clear
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.copy
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.elements
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.items
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.iteritems
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.iterkeys
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.itervalues
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.keys
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.most_common
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.subtract
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.update
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.values
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.viewitems
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.viewkeys
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.viewvalues
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.from_selection
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__add__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__and__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__contains__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__delitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__eq__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__format__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__getitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__iter__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__len__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__makenew__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__missing__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__ne__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__or__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__repr__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__setitem__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__str__
   :noindex:

.. automethod:: abjad.tools.pitchtools.IntervalVector.IntervalVector.__sub__
   :noindex:
